{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "PyScripts" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("PyScripts") %}
{% endblock page_header %}

{% block main %}

    {{ table.render }}

{{ modules }}
{% endblock %}
