{% extends 'base.html' %}
{% load i18n %}

{% block title %}{% trans "Reporting" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Reporting") %}
{% endblock page_header %}


{% block main %}
<div class="row-fluid">
  <div class="col-sm-12">
    {{ tab_group.render }}
  </div>
</div>

{% endblock %}
